@@ -9,7 +9,39 @@ from .text_input import *
 from .traits import *
 from .view import *
 
-__version__ = "2.0.0"
+__all__ = (
+    "Context",
+    "InteractionResponse",
+    "ModalContext",
+    "RawComponentContext",
+    "ViewContext",
+    "ModalContext",
+    "RawModalContext",
+    "install",
+    "uninstall",
+    "load",
+    "unload",
+    "Button",
+    "button",
+    "Event",
+    "ComponentInteractionCreateEvent",
+    "ModalInteractionCreateEvent",
+    "MiruException",
+    "BootstrapFailureError",
+    "RowFullError",
+    "HandlerFullError",
+    "ItemAlreadyAttachedError",
+    "Modal",
+    "SelectOption",
+    "Select",
+    "select",
+    "TextInput",
+    "MiruAware",
+    "View",
+    "get_view",
+)
+
+__version__ = "2.0.4"
 
 # MIT License
 #
